==> 0.3.1%2B3.tar.gz: ios/Classes/Classes/services/BackgroundBeaconScanner.swift <==
import Foundation
import CoreLocation

public class BackgroundBeaconScanner: NSObject, CLLocationManagerDelegate{
    
    public static let shared = BackgroundBeaconScanner();
    open var delegate: SnowMBackgroundScanningServiceDelegate?
    
    private let locationManager = CLLocationManager()
    
    private var regionStatus: Dictionary<String, Bool> = Dictionary()
    private var customData: Dictionary<String,Any>?
    private var uuids: [String]?
    
    override init(){
        super.init()
        locationManager.pausesLocationUpdatesAutomatically = false
        if #available(iOS 9.0, *) {
            locationManager.allowsBackgroundLocationUpdates = true
        }
        locationManager.delegate = self;
    }
    
    public func scanBeacons(uuids:[String], customData: Dictionary<String,Any>){
        locationManager.requestAlwaysAuthorization()
        locationManager.startUpdatingLocation()
        UserDefaults.standard.setValue(uuids, forKey: "uuids")
        UserDefaults.standard.setValue(customData, forKey: "customData")
        startBeaconRanging()
    }
    
    public func startBeaconRanging(){
        getDataFromStorage()
        uuids!.forEach { (id) in
            let uuid = UUID(uuidString: id)
            let region = CLBeaconRegion(proximityUUID: uuid!, identifier: id)
            locationManager.startMonitoring(for: region)
            locationManager.startRangingBeacons(in: region)
        }
    }
    
    public func addGeoFencing(location: CLLocationCoordinate2D, radius: CLLocationDistance){
        let region = CLCircularRegion(center: CLLocationCoordinate2D(), radius: radius, identifier: "geofencing")
        region.notifyOnExit = true
        region.notifyOnEntry = true
        locationManager.startMonitoring(for: region)
    }
    
    public func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        delegate?.onLocationUpdated(locations: locations)
    }
    
    public func removeBeaconRanging(){
        for region in locationManager.rangedRegions {
            if(region is CLBeaconRegion){
                locationManager.stopRangingBeacons(in: region as! CLBeaconRegion)
            }
        }
    }
    
    public func removeBeaconMonitoring(){
        for region in locationManager.monitoredRegions {
            if(region is CLBeaconRegion){
                locationManager.stopMonitoring(for: region)
            }
        }
    }
    
    public func removeGeofencing(){
        for region in locationManager.monitoredRegions {
            if(region is CLCircularRegion){
                locationManager.stopMonitoring(for: region)
            }
        }
    }
    
    public func locationManager(_ manager: CLLocationManager, didExitRegion region: CLRegion) {
        if region is CLCircularRegion{
            delegate?.didExitGeofence()
            removeBeaconRanging()
            removeBeaconMonitoring()
        } else {
            regionStatus[region.identifier] = false
            let didAllExit = !regionStatus.values.contains(true)
            if(didAllExit) {
                delegate?.onRegionExited()
                removeBeaconRanging()
            }
        }
    }
    
    private func getDataFromStorage(){
        uuids = UserDefaults.standard.array(forKey: "uuids") as! [String]
        customData = UserDefaults.standard.dictionary(forKey: "customData")!
    }
    
    public func locationManager(_ manager: CLLocationManager, didEnterRegion region: CLRegion) {
        if region is CLCircularRegion{
            delegate?.didEnterGeofence()
            startBeaconRanging()
        } else if region is CLBeaconRegion{
            let didAllExit = !regionStatus.values.contains(true)
            if(didAllExit) {
                startBeaconRanging()
                delegate?.onRegionEntered()
            }
            regionStatus[region.identifier] = true
        }
    }
    
    public func locationManager(_ manager: CLLocationManager, didRangeBeacons beacons: [CLBeacon], in region: CLBeaconRegion) {
        if (beacons.count==0) {return}
        let snowmBeacons:[SnowMBeacon] = beacons.map {
            let snowmBeacon = SnowMBeacon()
            snowmBeacon.uuid = $0.proximityUUID.uuidString
            snowmBeacon.major = $0.major.intValue
            snowmBeacon.minor = $0.minor.intValue
            snowmBeacon.txPower = 0
            snowmBeacon.macAddress = "Unavailable"
            snowmBeacon.distance = $0.accuracy.distance(to: 1)
            snowmBeacon.rssi = $0.rssi
            return snowmBeacon
        }
        delegate?.onBeaconDetected(beacons: snowmBeacons, customData: customData)
    }
    
    public func locationManager(_ manager: CLLocationManager, rangingBeaconsDidFailFor region: CLBeaconRegion, withError error: Error) {
    }
}

==> 0.4.2%2B3.tar.gz: ios/Classes/Classes/services/BackgroundBeaconScanner.swift <==
import Foundation
import CoreLocation

public class BackgroundBeaconScanner: NSObject, CLLocationManagerDelegate{
    
    public static let shared = BackgroundBeaconScanner();
    open var delegate: SnowMBackgroundScanningServiceDelegate?
    
    private let locationManager = CLLocationManager()
    
    private var regionStatus: Dictionary<String, Bool> = Dictionary()
    private var customData: Dictionary<String,Any>?
    private var uuids: [String]?
    
    override init(){
        super.init()
        locationManager.pausesLocationUpdatesAutomatically = false
        if #available(iOS 9.0, *) {
            locationManager.allowsBackgroundLocationUpdates = true
        }
        locationManager.delegate = self;
    }
    
    public func scanBeacons(uuids:[String], customData: Dictionary<String,Any>){
        locationManager.requestAlwaysAuthorization()
        locationManager.startUpdatingLocation()
        UserDefaults.standard.setValue(uuids, forKey: "uuids")
        do{
            let data = try JSONSerialization.data(withJSONObject: customData, options: .prettyPrinted)
            let jsonData = String(data: data, encoding: .ascii)
            UserDefaults.standard.setValue(jsonData, forKey: "customData")
        } catch {
            print(error)
        }
        startBeaconRanging()
    }
    
    public func startBeaconRanging(){
        getDataFromStorage()
        uuids!.forEach { (id) in
            let uuid = UUID(uuidString: id)
            let region = CLBeaconRegion(proximityUUID: uuid!, identifier: id)
            locationManager.startMonitoring(for: region)
            locationManager.startRangingBeacons(in: region)
        }
    }
    
    public func addGeoFencing(identifier:String, location: CLLocationCoordinate2D, radius: CLLocationDistance){
        let region = CLCircularRegion(center: location, radius: radius, identifier: identifier)
        region.notifyOnExit = true
        region.notifyOnEntry = true
        locationManager.startMonitoring(for: region)
    }
    
    public func locationManager(_ manager: CLLocationManager, didUpdateLocations locations: [CLLocation]) {
        delegate?.onLocationUpdated(locations: locations)
    }
    
    public func removeBeaconRanging(){
        for region in locationManager.rangedRegions {
            if(region is CLBeaconRegion){
                locationManager.stopRangingBeacons(in: region as! CLBeaconRegion)
            }
        }
    }
    
    public func removeBeaconMonitoring(){
        for region in locationManager.monitoredRegions {
            if(region is CLBeaconRegion){
                locationManager.stopMonitoring(for: region)
            }
        }
    }
    
    public func removeGeofencing(identifier:String){
        for region in locationManager.monitoredRegions {
            if(region is CLCircularRegion){
                if(region.identifier == identifier){
                    locationManager.stopMonitoring(for: region)
                }
            }
        }
    }
    
    public func locationManager(_ manager: CLLocationManager, didEnterRegion region: CLRegion) {
        if region is CLCircularRegion{
            delegate?.didEnterGeofence()
            if(region.identifier.contains("backgroundGeofence")) {
                startBeaconRanging()
            }
        } else if region is CLBeaconRegion{
            let didAllExit = !regionStatus.values.contains(true)
            if(didAllExit) {
                startBeaconRanging()
                delegate?.onRegionEntered()
            }
            regionStatus[region.identifier] = true
        }
    }
    
    public func locationManager(_ manager: CLLocationManager, didExitRegion region: CLRegion) {
        if region is CLCircularRegion{
            delegate?.didExitGeofence()
            if(region.identifier.contains("backgroundGeofence")) {
                // TODO: Check geo fencing here
                // removeBeaconMonitoring()
                removeBeaconRanging()
            }
        } else {
            regionStatus[region.identifier] = false
            let didAllExit = !regionStatus.values.contains(true)
            if(didAllExit) {
                delegate?.onRegionExited()
                removeBeaconRanging()
            }
        }
    }
    
    private func getDataFromStorage(){
        uuids = UserDefaults.standard.stringArray(forKey: "uuids")!
        let jsonData: String? = UserDefaults.standard.string(forKey: "customData")
        if(jsonData != nil){
            do{
                let data = jsonData?.data(using: .utf8)
                let decoded = try JSONSerialization.jsonObject(with: data!, options: [])
                customData = decoded as! Dictionary<String, Any>
            } catch{
                print(error)
            }
        }
    }
    
    
    
    public func locationManager(_ manager: CLLocationManager, didRangeBeacons beacons: [CLBeacon], in region: CLBeaconRegion) {
        if (beacons.count==0) {return}
        let snowmBeacons:[SnowMBeacon] = beacons.map {
            let snowmBeacon = SnowMBeacon()
            snowmBeacon.uuid = $0.proximityUUID.uuidString
            snowmBeacon.major = $0.major.intValue
            snowmBeacon.minor = $0.minor.intValue
            snowmBeacon.txPower = 0
            snowmBeacon.macAddress = "Unavailable"
            snowmBeacon.distance = $0.accuracy.distance(to: 1)
            snowmBeacon.rssi = $0.rssi
            return snowmBeacon
        }
        delegate?.onBeaconDetected(beacons: snowmBeacons, customData: customData)
    }
    
    public func locationManager(_ manager: CLLocationManager, rangingBeaconsDidFailFor region: CLBeaconRegion, withError error: Error) {
    }
}
